<template>
  <ChooseInput :modelValue="inputValue" @click="handleOpen()"></ChooseInput>
</template>

<script setup lang="ts">
import { useAllAreaList } from '@12333/hooks';
import { Portal } from 'senin-mini/components';
import ChooseInput from './ChooseInput.vue';
import { Popup, Picker } from '@nutui/nutui-taro';
import { computed, h } from 'vue';

defineOptions({
  name: 'ChooseInputWithAreaPicker',
});

const { findAreaNameFromCode } = useAllAreaList();

type Props = {
  fieldNames?: object;
  columns: API.AreaTreeNode[];
  modelValue: Array<string | number>;
  title?: string;
};

const props = withDefaults(defineProps<Props>(), {
  title: '选择地址',
  fieldNames: () => ({
    text: 'areaName',
    value: 'areaCode',
    children: 'children',
  }),
});
const inputValue = computed(() =>
  props.modelValue.map((x) => findAreaNameFromCode(Number(x))).join(',')
);

const emit = defineEmits<{
  (e: 'update:modelValue', val: Array<string | number>): void;
}>();

function handleOpen() {
  Portal.add((key) => {
    return h(
      Portal.Container,
      { keyNumber: key, delayOpen: true },
      {
        default: ({ open, onClose }) =>
          h(
            Popup,
            {
              visible: open.value,
              'onUpdate:visible': (value) => !value && onClose(),
              position: 'bottom',
            },
            {
              default: () =>
                h(Picker, {
                  modelValue: props.modelValue,
                  columns: props.columns,
                  fieldNames: props.fieldNames,
                  title: props.title,
                  onCancel: onClose,
                  onConfirm: ({ selectedValue, selectedOptions }) => {
                    emit(
                      'update:modelValue',
                      selectedOptions.map((x) => x.areaCode)
                    );
                    onClose();
                  },
                }),
            }
          ),
      }
    );
  });
}
</script>
